package io.swagger.test_swagger_java_client;

import io.swagger.client.*;
import io.swagger.client.auth.*;
import io.swagger.client.model.*;
import io.swagger.client.api.LoginApi;
import io.swagger.client.model.JwtDto;
import io.swagger.client.model.UserDto;
import io.swagger.client.ApiResponse;
import io.swagger.client.model.CustomerDto;
import io.swagger.client.api.CustomersApi;
import io.swagger.client.model.ClusterDto;
import io.swagger.client.api.ClustersApi;
import io.swagger.client.model.PaginatedDto;
import io.swagger.client.model.EndDeviceDto;
import io.swagger.client.api.EndDevicesApi;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.fail;


public class App_EndDeviceAPITest extends AbstractTest {
	
	public static CustomerDto createCustomer(CustomerDto customerDto, CustomersApi customerInstance) throws ApiException {

		Long id = null;
		
		if(customerDto == null) {
			customerDto = new CustomerDto();
			ApiResponse<String> customerResponse = customerInstance.createCustomerWithHttpInfo(customerDto);
			id = getIdFromResponse(customerResponse);
			customerDto.setId(id);
		} else {
			if (customerDto.getId() == null) {
				ApiResponse<String> customerResponse = customerInstance.createCustomerWithHttpInfo(customerDto);
				id = getIdFromResponse(customerResponse);
				customerDto.setId(id);
			} else {
				id = customerDto.getId();
			}
		}

		assertNotNull(id);
		
		customerDto = customerInstance.getCustomer(id, null);

		return customerDto;
	}
	
	public static ClusterDto createCluster(ClusterDto ClusterDto, ClustersApi ClusterInstance, CustomerDto customerDto) throws ApiException {

		Long id = null;
		
		if (customerDto != null) {
			if(ClusterDto == null) {
				ClusterDto = new ClusterDto();
				ClusterDto.setCustomer(customerDto.toId());
				ApiResponse<String> ClusterResponse = ClusterInstance.createClusterWithHttpInfo(ClusterDto);
				id = getIdFromResponse(ClusterResponse);
			} else {
				if (ClusterDto.getId() == null) {				
					ClusterDto.setCustomer(customerDto.toId());
					ApiResponse<String> ClusterResponse = ClusterInstance.createClusterWithHttpInfo(ClusterDto);
					id = getIdFromResponse(ClusterResponse);
				} else {
					id = ClusterDto.getId();
				}
			}
	
			assertNotNull(id);
			
			ClusterDto = ClusterInstance.getCluster(id, null);
		}
		
		return ClusterDto;
	}

	public static EndDeviceDto createEndDevice(CustomerDto customerDto , ClusterDto clusterDto, EndDeviceDto endDeviceDto, EndDevicesApi endDevicesInstance) throws ApiException {


		if(endDeviceDto == null) {						

			endDeviceDto.setCluster(clusterDto.toId());
			
			ApiResponse<String> clusterResponse = endDevicesInstance.putEndDeviceWithHttpInfo(endDeviceDto, endDeviceDto.getDevEui());

		} else {

			endDeviceDto.setCluster(clusterDto.toId());					
			ApiResponse<String> clusterResponse = endDevicesInstance.putEndDeviceWithHttpInfo(endDeviceDto, endDeviceDto.getDevEui());
		}
							
		assertNotNull(endDeviceDto.getDevEui());

		//get
		endDeviceDto = endDevicesInstance.getEndDevice(endDeviceDto.getDevEui(), null);

		return endDeviceDto;
	}


    public static void main(String[] args) throws ApiException {

      long id1=0, id_Cluster=0; 	

      // Say Hello
      System.out.println("Hello world");
        
      String baseApiUrl = "https://wmcintegration.wanesy.com/";
  	  int connectTimeout = 60000;
  	  
  	  // Create an ApiClient per thread
  	  ApiClient defaultClient = Configuration.getDefaultApiClient();
  	  
  	  defaultClient.setBasePath(baseApiUrl); 	  
  	  defaultClient.setConnectTimeout(connectTimeout);
  	  defaultClient.setDebugging(true);
  	
  	  // login 
  	  
  	  LoginApi loginApi = new LoginApi(defaultClient);
  	  
  	  UserDto body = new UserDto ();
  	  body.setLogin("your_login");
  	  body.setPassword("your_password");
  	  
  	  System.out.println("Login Post");
  	
  	  JwtDto jwt = loginApi.login(body);
	
  	  defaultClient.setApiKey("Bearer " + jwt.getToken());
  	  Configuration.setDefaultApiClient(defaultClient);
  	 
	 //createCustomer
  	  
  	 CustomersApi customerInstance = new CustomersApi();
	 CustomerDto customerDto = new CustomerDto();
	 	
  	 try {  
		 	  		
  		 	customerDto.setName("My company");  		 	
  		 	customerDto = createCustomer(customerDto, customerInstance);
  		 	id1 = customerDto.getId();
		  	System.out.println("CustomerId="+id1);	
		  	
	  } catch (ApiException e) {
	  	    System.err.println("Exception when calling CustomersApi#createCustomer");
	  	    e.printStackTrace();   
	  }
  	 
	  // getCustomers - a single instance
	  
  	  String sort = ""; // Sort value
	  String pageSize = ""; // Page size value
	  String search = "{\"operand\": \"name\", \"operation\": \"EQ\",	\"values\": [\"My company\"]}"; // Search condition
	  String fields = ""; // List of fields to display
	  String page = ""; // Page number
	  try {
		  PaginatedDto<CustomerDto> paginatedDto =  customerInstance.getCustomers(fields, page, pageSize, search, sort);
	  	  assertEquals(Integer.valueOf(1), paginatedDto.getCount());
	  	  
	  } catch (ApiException e) {
	  	    System.err.println("Exception when calling CustomersApi#applicationCustomersGet");
	  	    e.printStackTrace();
	  }
  	    
	  
	  // createCluster
	  ClustersApi clusterInstance = new ClustersApi();
	  ClusterDto clusterDto = new ClusterDto();
	  
	  try { 		  
		  
		  clusterDto.setName("My Cluster");
		  clusterDto = createCluster(clusterDto, clusterInstance, customerDto);
		  id_Cluster = clusterDto.getId();
		  System.out.println("ClusterId="+id_Cluster);	
	  }
	  catch (ApiException e) {
	  	    System.err.println("Exception when calling ClustersApi#createCluster");
	  	    e.printStackTrace();   
	  }
	  
	  // getClusters
	  
	  sort = ""; // Sort value
	  pageSize = ""; // Page size value
	  search = "{\"operand\": \"name\", \"operation\": \"EQ\",	\"values\": [\"My Cluster\"]}"; // Search condition
	  fields = ""; // List of fields to display
	  page = ""; // Page number
	  try {
		  PaginatedDto<ClusterDto> paginatedDto =  clusterInstance.getClusters(fields, page, pageSize, search, sort);
	  	  assertEquals(Integer.valueOf(1), paginatedDto.getCount());
	  	  
	  } catch (ApiException e) {
	  	    System.err.println("Exception when calling ClustersApi#getClusters");
	  	    e.printStackTrace();
	  }
  	    
	  // getCluster
	  
	  clusterDto = clusterInstance.getCluster(id_Cluster, null);
	  System.out.println("The Cluster Id="+id_Cluster+" has name \""+clusterDto.getName()+"\"");	
	  
	  // CreateEndDevice
	  
	  EndDevicesApi endDevicesInstance = new EndDevicesApi();
	  EndDeviceDto endDeviceDto = new EndDeviceDto();
	  endDeviceDto = new EndDeviceDto();
	  endDeviceDto.setName("My end-device");
	  endDeviceDto.setProfile("walking");
	  endDeviceDto.setClassType("A");
	  endDeviceDto.setAdrEnabled(true);
	  endDeviceDto.setRfRegion("EU868");
	  endDeviceDto.setMacVersion("1.0.1");
	  endDeviceDto.setRegParamsRevision("");
		
	  endDeviceDto.setActivation("ABP");
	  endDeviceDto.setDevEui("1234567897894561");
	  endDeviceDto.setAppSKey("12345678978945612345678945612345");
	  endDeviceDto.setNwkSKey("12345678978945612345678945612345");
	  endDeviceDto.setDevAddr("12345678");
	  endDeviceDto.setGeolocation("Inherited");
	  createEndDevice(customerDto , clusterDto, endDeviceDto, endDevicesInstance);
	  
	  //deleteEndDevice
	  
	  endDevicesInstance.deleteEndDevice(endDeviceDto.getDevEui());
	  System.out.println("The EndDevice DevEui="+endDeviceDto.getDevEui()+" has been deleted=");
	  
	  // deleteCluster
	  
	  clusterInstance.deleteCluster(id_Cluster);
	  System.out.println("The Cluster Id="+id_Cluster+" has been deleted=");
	  
	  // deleteCustomer
	  
	  customerInstance.deleteCustomer(id1);
	  System.out.println("The customer Id="+id1+" has been deleted");
  }
}
    
    